==> tine20-allinone_2019.12.5.tar.bz2: Addressbook/js/Addressbook-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pt_BR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Informação Comercial do Contato"

, "Organisation / Unit"
: "Organização / Unidade"

, "Business Address"
: "Endereço Comercial"

, "Email"
: "Email"

, "Telephone Work"
: "Telefone de trabalho"

, "Telephone Cellphone"
: "Telefone Celular"

, "Telephone Car"
: "Telefone do Carro"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: "Página do Telefone"

, "URL"
: "URL"

, "Role"
: "Perfil"

, "Room"
: "Sala"

, "Assistant"
: "Assistente"

, "Assistant Telephone"
: "Telefone do Assistente"

, "Private Contact Data"
: "Informação Pessoal do Contato"

, "Private Address"
: "Endereço Particular"

, "Email Home"
: "Email Residencial"

, "Telephone Home"
: "Telefone Residencial"

, "Telephone Cellphone Private"
: "Telefone Celuar Particular"

, "Telephone Fax Home"
: "Fax Residencial"

, "URL Home"
: "URL Residencial"

, "Other Data"
: "Outras Informações"

, "Birthday"
: "Aniversário"

, "Job Title"
: "Título do Trabalho"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  "Lista"
 ,"Listas"

]
, "Percent"
: ""

, "Description"
: "Descrição"

, "Members"
: "Membros"

, "Type"
: "Tipo"

, "List type"
: "Listar tipo"

, "Addressbook, Addressbooks"
: [
  "Catálogo de Endereço"
 ,"Catálogo de Endereços"

]
, "Contact, Contacts"
: [
  "Contato"
 ,"Contatos"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "País"

, "City"
: "Cidade"

, "Postalcode"
: "Código Postal"

, "Region"
: "Estado"

, "Street"
: "Rua"

, "Street 2"
: "Rua 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "País (particular)"

, "City (private)"
: "Cidade (particular)"

, "Postalcode (private)"
: "Código postal (particular)"

, "Region (private)"
: "Município (particular)"

, "Street (private)"
: "Rua (particular)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Email (particular)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geo"

, "Groups"
: "Grupos"

, "Industry, Industries"
: [
  "Indústrias"
 ,"Indústrias"

]
, "Note"
: "Lembrete"

, "Last Name"
: "Sobrenome"

, "Display Name"
: "Exibir Nome"

, "Full Name"
: "Nome Completo"

, "First Name"
: "Prenome"

, "Middle Name"
: "Nome do Meio"

, "Title"
: "Título"

, "Suffix"
: "Sufixo"

, "Company"
: "Empresa"

, "Unit"
: "Unidade"

, "Paths"
: ""

, "Preferred Address"
: "Endereço Preferido"

, "Job Role"
: "Função"

, "Salutation"
: "Saudação"

, "syncBackendIds"
: ""

, "Car phone"
: "Telefone do carro"

, "Mobile"
: "Celular"

, "Mobile (private)"
: "Celular (particular)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (particular)"

, "Phone (private)"
: "Telefone (particular)"

, "Pager"
: "Pager"

, "Phone"
: "Telefone"

, "Timezone"
: "Fuso horário"

, "Web"
: "Web"

, "URL (private)"
: "URL (particular)"

, "Label"
: ""

, "Lists"
: "Listas"

, "Select list"
: "Selecionar lista"

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: "Campos personalizados"

, "Related to"
: "Relacionado a"

, "Contact Information"
: "Informação de Contato"

, "Company Address"
: "Endereço da Empresa"

, "New Contact"
: "Novo Contato"

, "ID"
: "ID"

, "Name"
: "Nome"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: "Importar contatos"

, "Contact of a user account"
: "Contado da conta do usuário"

, "No name"
: "Sem nome"

, "Business"
: "Negócios"

, "Private"
: "Particular"

, "Not set"
: "Não configurado"

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Identificações"

, "List Roles"
: ""

, "Street (Company Address)"
: "Rua (Endereço Comercial)"

, "Street 2 (Company Address)"
: "Rua 2 (Endereço Comercial)"

, "City (Company Address)"
: "Cidade (Endereço Comercial)"

, "Region (Company Address)"
: "Municipio (Endereço Comercial)"

, "Postal Code (Company Address)"
: "Código Postal (Endereço Comercial)"

, "Country (Company Address)"
: "País (Endereço Comercial)"

, "Longitude (Company Address)"
: "Longitude (Endereço da Empresa)"

, "Latitude (Company Address)"
: "Latitude (Endereço da Empresa)"

, "Street (Private Address)"
: "Rua (Endereço Privado)"

, "Street 2 (Private Address)"
: "Rua 2 (Endereço Privado)"

, "City (Private Address)"
: "Cidade (Endereço Privado)"

, "Region (Private Address)"
: "Município (Endereço Privado)"

, "Postal Code (Private Address)"
: "Código Postal (Endereço Particular)"

, "Country (Private Address)"
: "País (Endereço Particular)"

, "Company Communication"
: "Companhia de Comunicação"

, "Private Communication"
: "Comunicação Particular"

, "E-Mail"
: "E-mail"

, "E-Mail (private)"
: "-mail (particular)"

, "Web (private)"
: "Web (particular)"

, "Contacts"
: "Contatos"

, "Addressbooks"
: "Catálogo de Endereços"

, "User Account"
: "Conta do Usuário"

, "Quick Search"
: "Busca Rápida"

, "Postal Code"
: "Código Postal"

, "Last Modified Time"
: "Hora do Último Modificaco"

, "Last Modified By"
: "Último Modificado Por"

, "Creation Time"
: "Hora da Criação"

, "Created By"
: "Criado Por"

, "Email Address, Email Addresses"
: [
  "Endereços de e-mail"
 ,"Endereços de e-mail"

]
, "Email Addresses"
: "Endereços de e-mail"

, "Quick search"
: "Busca rápida"

, "List Function, List Functions"
: [
  "Listar Funções"
 ,"Listar Funções"

]
, "List Functions"
: "Listar Funções"

, "Industries"
: "Indústrias"

, "Structures"
: ""

, "List Information"
: "Listar Informação"

, "Enter description"
: "Informar descrição"

, "{0} must be given"
: "{0} deve ser fornecido"

, "Member of List"
: "Membro da Lista (Endereço Comercial)"

, "Map"
: "Mapa"

, "Company address"
: "Endereço da Empresa"

, "Private address"
: "Endereço particular"

, "CardDAV URL"
: "URL do CardDAV"

, "Search for system groups ..."
: "Busca por grupos de sistema..."

, "Search for groups ..."
: "Busca por grupos..."

, "Personal Information"
: "Informação Pessoal"

, "Parse address"
: "Analisar endereço"

, "Print contact"
: "Imprime contato"

, "Paste address"
: "Colar endereço"

, "Please paste an address or a URI to a vcard that should be parsed:"
: "Por favor, cole um endereço ou um URI para um vcard que deve ser processado"

, "Failed to parse address!"
: "Falha em processar endereço!"

, "The address could not be read."
: "O endereço não pode ser lido"

, "End token mode"
: "Finalizar o modo de símbolos"

, "Remove Member"
: "Remover Membro"

, "Emails"
: "Emails"

, "System Group"
: "Grupo de Sistema"

, "Group"
: "Grupo"

, "Search for users ..."
: "Buscar por usuários..."

, "Search for Contacts ..."
: "Buscar por Contatos"

, "All contacts"
: "Todos os contatos"

, "Default Addressbook"
: "Catálogo de Endereços Padrão"

, "The default addressbook for new contacts"
: "O Catálogo de Endereços padrão para novos contatos"

, "Default Favorite"
: "Favorito Padrão"

, "The default favorite which is loaded on addressbook startup"
: "Meu favorito padrão que é carregado no Catálogo de Endereços no começo"

, "Contacts ODS export configuration"
: "Configuração de exportação de Contatos para ODS"

, "Use this configuration for the contact ODS export."
: "Usar esta configuração para a exportação do contato para ODS"

, "Contacts XLS export configuration"
: "Configuração de exportação de contatos para XLS"

, "Use this configuration for the contact XLS export."
: "Usar esta configuração para a exportação do contato para XLS"

, "default"
: "padrão"

, "All Contacts"
: "Todos Contatos"

, "This contact has been automatically added by the system as an event attender"
: "Este contato foi automaticamente adicionado pelo sistema como um participante do evento"

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: "Contato dupliado: verifique as informações"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Esses campos foram verificados quando o novo contato foi criado.  Se o registro com o a mesma informação for encontrado, uma exceção de duplicata é exibida."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Saudações de Contato disponível"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Saudações de contatos possíveis. Note que valores adicionais poderiam impactar em Catálogos de Endereços de outros sistemas durante a exportação ou sincronização."

, "Mr"
: "Sr"

, "Ms"
: "Sra"

, "Parsing rules for addresses"
: "Regras de análise para endereços"

, "Path to a XML file with address parsing rules."
: "Caminho para o arquivo XML com regras de análise de endereço"

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Importação de contato do VCARD"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Importar lista (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Contatos importados em ###CURRENTDATE### na ###CURRENTTIME### por ###USERFULLNAME###"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "Arquivo CSV do Outlook 2007 em Alemão"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Importação de arquivo CSV do livro de endereços do Outlook"

, "Contact CSV import from mac address book"
: "Importação de contato do livro de endereços do Mac"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importação de contato do livro de endereços do Google"

, "manage shared addressbooks"
: "gerencie Catálogos de Endereços compartilhados"

, "Create new shared addressbook folders"
: "Criar novas pastas compartilhadas no Catálogo de Endereços"

, "manage shared addressbook favorites"
: "gerenciar os favoritos compartilhados do Catálogo de Endereços"

, "Create or update shared addressbook favorites"
: "Criar ou atualizar favoritos compartilhados no Caderno de Endereços"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "%s's caderno de endereço pessoal"

, "All contacts I have read grants for"
: "Todos os contatos que eu marquei como privilégio"

, "My company"
: "Minha empresa"

, "All coworkers in my company"
: "Todos os colegas de trabalho na minha empresa"

, "My contacts"
: "Meus contatos"

, "All contacts in my Addressbooks"
: "Todos os contatos no meu Caderno de Endereço"

, "Last modified by me"
: "Último modificado por mim"

, "All contacts that I have last modified"
: "Todos os contatos que eu modifiquei por último"

, "Internal Contacts"
: "Contatos Internos"

, "List"
: "Lista"

, "Addressbook"
: "Catálogo de Endereço"

, "Contact"
: "Contato"

, "Industry"
: "Indústrias"

, "Structure"
: ""

, "Email Address"
: "Endereços de e-mail"

, "List Function"
: "Listar Funções"

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Addressbook/js/Addressbook-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: "Mapa"

, "Preferred Address"
: "Endereço Preferido"

, "Personal Information"
: "Informação Pessoal"

, "Salutation"
: "Saudação"

, "Title"
: "Título"

, "Short Name"
: ""

, "First Name"
: "Prenome"

, "Middle Name"
: "Nome do Meio"

, "Last Name"
: "Sobrenome"

, "Company"
: "Empresa"

, "Unit"
: "Unidade"

, "Display Name"
: "Exibir Nome"

, "Industry, Industries"
: [
  "Indústrias"
 ,"Indústrias"

]
, "Job Title"
: "Título do Trabalho"

, "Birthday (private)"
: ""

, "Contact Information"
: "Informação de Contato"

, "Phone"
: "Telefone"

, "Mobile"
: "Celular"

, "Fax"
: "Fax"

, "Phone (private)"
: "Telefone (particular)"

, "Mobile (private)"
: "Celular (particular)"

, "Fax (private)"
: "Fax (particular)"

, "E-Mail"
: "E-mail"

, "E-Mail (private)"
: "-mail (particular)"

, "Web"
: "Web"

, "Company Address"
: "Endereço da Empresa"

, "Street"
: "Rua"

, "Street 2"
: "Rua 2"

, "Region"
: "Estado"

, "Postal Code"
: "Código Postal"

, "City"
: "Cidade"

, "Country"
: "País"

, "Private Address"
: "Endereço Particular"

, "Description"
: "Descrição"

, "Enter description"
: "Informar descrição"

, "Groups"
: "Grupos"

, "Parse address"
: "Analisar endereço"

, "Print contact"
: "Imprime contato"

, "Paste address"
: "Colar endereço"

, "Please paste an address or a URI to a vcard that should be parsed:"
: "Por favor, cole um endereço ou um URI para um vcard que deve ser processado"

, "Failed to parse address!"
: "Falha em processar endereço!"

, "The address could not be read."
: "O endereço não pode ser lido"

, "End token mode"
: "Finalizar o modo de símbolos"

, "Customfields"
: "Campos personalizados"

, "Related to"
: "Relacionado a"

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: "Busca por grupos de sistema..."

, "Search for groups ..."
: "Busca por grupos..."

, "Contact, Contacts"
: [
  "Contato"
 ,"Contatos"

]
, "Members"
: "Membros"

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: "Remover Membro"

, "CardDAV URL"
: "URL do CardDAV"

, "New Contact"
: "Novo Contato"

, "Addressbook, Addressbooks"
: [
  "Catálogo de Endereço"
 ,"Catálogo de Endereços"

]
, "ID"
: "ID"

, "Name"
: "Nome"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Private"
: "Particular"

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""
 ,""

]
, "List Personal Grant, List Personal Grants"
: [
  ""
 ,""

]
, "List Information"
: "Listar Informação"

, "List type"
: "Listar tipo"

, "System accounts only"
: ""

, "{0} must be given"
: "{0} deve ser fornecido"

, "List Functions"
: "Listar Funções"

, "Suffix"
: "Sufixo"

, "Birthday"
: "Aniversário"

, "Job Role"
: "Função"

, "Room"
: "Sala"

, "Street (Company Address)"
: "Rua (Endereço Comercial)"

, "Street 2 (Company Address)"
: "Rua 2 (Endereço Comercial)"

, "City (Company Address)"
: "Cidade (Endereço Comercial)"

, "Region (Company Address)"
: "Municipio (Endereço Comercial)"

, "Postal Code (Company Address)"
: "Código Postal (Endereço Comercial)"

, "Country (Company Address)"
: "País (Endereço Comercial)"

, "Longitude (Company Address)"
: "Longitude (Endereço da Empresa)"

, "Latitude (Company Address)"
: "Latitude (Endereço da Empresa)"

, "Street (Private Address)"
: "Rua (Endereço Privado)"

, "Street 2 (Private Address)"
: "Rua 2 (Endereço Privado)"

, "City (Private Address)"
: "Cidade (Endereço Privado)"

, "Region (Private Address)"
: "Município (Endereço Privado)"

, "Postal Code (Private Address)"
: "Código Postal (Endereço Particular)"

, "Country (Private Address)"
: "País (Endereço Particular)"

, "Company Communication"
: "Companhia de Comunicação"

, "Private Communication"
: "Comunicação Particular"

, "Web (private)"
: "Web (particular)"

, "Contacts"
: "Contatos"

, "Addressbooks"
: "Catálogo de Endereços"

, "User Account"
: "Conta do Usuário"

, "Quick Search"
: "Busca Rápida"

, "Type"
: "Tipo"

, "Last Modified Time"
: "Hora do Último Modificaco"

, "Last Modified By"
: "Último Modificado Por"

, "Creation Time"
: "Hora da Criação"

, "Created By"
: "Criado Por"

, "List, Lists"
: [
  "Lista"
 ,"Listas"

]
, "Lists"
: "Listas"

, "Email Address, Email Addresses"
: [
  "Endereços de e-mail"
 ,"Endereços de e-mail"

]
, "Email Addresses"
: "Endereços de e-mail"

, "Quick search"
: "Busca rápida"

, "List Function, List Functions"
: [
  "Listar Funções"
 ,"Listar Funções"

]
, "GENDER_List Function"
: ""

, "Industries"
: "Indústrias"

, "Structures"
: ""

, "Business"
: "Negócios"

, "Import contacts"
: "Importar contatos"

, "Contact of a user account"
: "Contado da conta do usuário"

, "No name"
: "Sem nome"

, "Not set"
: "Não configurado"

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Identificações"

, "Full Name"
: "Nome Completo"

, "Postalcode"
: "Código Postal"

, "Street (private)"
: "Rua (particular)"

, "City (private)"
: "Cidade (particular)"

, "Region (private)"
: "Município (particular)"

, "Postalcode (private)"
: "Código postal (particular)"

, "Country (private)"
: "País (particular)"

, "Email"
: "Email"

, "Car phone"
: "Telefone do carro"

, "Pager"
: "Pager"

, "Email (private)"
: "Email (particular)"

, "URL (private)"
: "URL (particular)"

, "Note"
: "Lembrete"

, "Timezone"
: "Fuso horário"

, "Geo"
: "Geo"

, "Select list"
: "Selecionar lista"

, "Search for users ..."
: "Buscar por usuários..."

, "Search for Contacts ..."
: "Buscar por Contatos"

, "Company address"
: "Endereço da Empresa"

, "Private address"
: "Endereço particular"

, "Member E-Mails"
: ""

, "System Group"
: "Grupo de Sistema"

, "Group"
: "Grupo"

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: "Todos os contatos"

, "Default Addressbook"
: "Catálogo de Endereços Padrão"

, "The default addressbook for new contacts"
: "O Catálogo de Endereços padrão para novos contatos"

, "Default Favorite"
: "Favorito Padrão"

, "The default favorite which is loaded on addressbook startup"
: "Meu favorito padrão que é carregado no Catálogo de Endereços no começo"

, "Contacts ODS export configuration"
: "Configuração de exportação de Contatos para ODS"

, "Use this configuration for the contact ODS export."
: "Usar esta configuração para a exportação do contato para ODS"

, "Contacts XLS export configuration"
: "Configuração de exportação de contatos para XLS"

, "Use this configuration for the contact XLS export."
: "Usar esta configuração para a exportação do contato para XLS"

, "default"
: "padrão"

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: "Contato dupliado: verifique as informações"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Esses campos foram verificados quando o novo contato foi criado.  Se o registro com o a mesma informação for encontrado, uma exceção de duplicata é exibida."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Saudações de Contato disponível"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Saudações de contatos possíveis. Note que valores adicionais poderiam impactar em Catálogos de Endereços de outros sistemas durante a exportação ou sincronização."

, "Mr"
: "Sr"

, "Ms"
: "Sra"

, "Parsing rules for addresses"
: "Regras de análise para endereços"

, "Path to a XML file with address parsing rules."
: "Caminho para o arquivo XML com regras de análise de endereço"

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "%s's caderno de endereço pessoal"

, "Business Contact Data"
: "Informação Comercial do Contato"

, "Organisation / Unit"
: "Organização / Unidade"

, "Business Address"
: "Endereço Comercial"

, "Telephone Work"
: "Telefone de trabalho"

, "Telephone Cellphone"
: "Telefone Celular"

, "Telephone Car"
: "Telefone do Carro"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: "Página do Telefone"

, "URL"
: "URL"

, "Role"
: "Perfil"

, "Assistant"
: "Assistente"

, "Assistant Telephone"
: "Telefone do Assistente"

, "Private Contact Data"
: "Informação Pessoal do Contato"

, "Email Home"
: "Email Residencial"

, "Telephone Home"
: "Telefone Residencial"

, "Telephone Cellphone Private"
: "Telefone Celuar Particular"

, "Telephone Fax Home"
: "Fax Residencial"

, "URL Home"
: "URL Residencial"

, "Other Data"
: "Outras Informações"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: ""

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Importação de arquivo CSV do livro de endereços do Outlook"

, "Contact CSV import from mac address book"
: "Importação de contato do livro de endereços do Mac"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "Arquivo CSV do Outlook 2007 em Alemão"

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Importação de contato do VCARD"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Importar lista (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Contatos importados em ###CURRENTDATE### na ###CURRENTTIME### por ###USERFULLNAME###"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importação de contato do livro de endereços do Google"

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "Contatos Internos"

, "All contacts I have read grants for"
: "Todos os contatos que eu marquei como privilégio"

, "My company"
: "Minha empresa"

, "All coworkers in my company"
: "Todos os colegas de trabalho na minha empresa"

, "My contacts"
: "Meus contatos"

, "All contacts in my Addressbooks"
: "Todos os contatos no meu Caderno de Endereço"

, "Last modified by me"
: "Último modificado por mim"

, "All contacts that I have last modified"
: "Todos os contatos que eu modifiquei por último"

, "All Contacts"
: "Todos Contatos"

, "This contact has been automatically added by the system as an event attender"
: "Este contato foi automaticamente adicionado pelo sistema como um participante do evento"

, "manage shared addressbooks"
: "gerencie Catálogos de Endereços compartilhados"

, "Create new shared addressbook folders"
: "Criar novas pastas compartilhadas no Catálogo de Endereços"

, "manage shared addressbook favorites"
: "gerenciar os favoritos compartilhados do Catálogo de Endereços"

, "Create or update shared addressbook favorites"
: "Criar ou atualizar favoritos compartilhados no Caderno de Endereços"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""
 ,""


]
, "Industry"
: "Indústrias"

, "Contact"
: "Contato"

, "Addressbook"
: "Catálogo de Endereço"

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: "Lista"

, "Email Address"
: "Endereços de e-mail"

, "List Function"
: "Listar Funções"

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
